@@ -4,6 +4,15 @@
 #include "Rmath.h"
 #include <setjmp.h>
 
+using std::atan;
+using std::exp;
+using std::sin;
+using std::log;
+using std::fabs;
+using std::sqrt;
+using std::floor;
+
+
 #define TRUE  1
 #define FALSE 0
 typedef int BOOL;
@@ -245,6 +254,10 @@ static double exp1(double x)               /* to avoid underflows  */
    }
 
 
+// Algorithm AS 155: The Distribution of a Linear Combination of χ2 Random Variables
+// Robert B. Davies
+// Journal of the Royal Statistical Society. Series C (Applied Statistics), Vol. 29, No. 3 (1980), pp. 323-333
+
 void  qfc(double* lb1, double* nc1, int* n1, int *r1, double *sigma, double *c1, int *lim1, double *acc, double* trace, int* ifault, double *res)
 
 /*  distribution function of a linear combination of non-central
